# Create the database tables needed by isoonline.  Please note that
# this removes the database if it already exists.

drop database if exists isoonline;
create database isoonline;
use isoonline;

create table base (
	dir_id int64 auto_increment	primary key not null,
	dir_name varchar(255)		not null,
	active bool			not null,
	last_scanned datetime		null,
	first_scanned datetime		null,

	UNIQUE(dir_name),
	INDEX(active, last_scanned)
);

create table file (
	file_id int64 auto_increment	primary key not null,
	filename varchar(255)		not null,
	dir_id int64			not null references base(dir_id),
	mtime datetime			not null,
	size int64			not null,
	md5sum  char(32)		not null,
	sha1sum char(40)		not null,
	
	# When was the on-line file last verified?
	verified datetime		not null,

	# Set if the on-line file is missing or modified.
	broken bool			not null,

	INDEX(filename),
	UNIQUE(filename, size, mtime, md5sum),
	INDEX(md5sum),
	INDEX(size)
);

create table media (
	media_id int32 auto_increment	primary key not null,
	written datetime		not null,
	verified datetime		null,
	broken bool			not null,

	INDEX(written),
	INDEX(verified)
);

create table contents (
	media int32			not null references media(media_id),
	file int64			not null references file(file_id),

	INDEX(file),
	INDEX(media)
);
